.page-link[data-v-471b148d]{height:10rem;min-width:10rem;display:flex;flex-direction:column;align-items:center;justify-content:center;gap:.5rem;border-radius:.25rem;background-color:#9ca3af1a;padding:1rem}.page-link[data-v-471b148d]:hover{background-color:#9ca3af33}.page-link>svg[data-v-471b148d]{font-size:3em;opacity:.5}
