import{c as s}from"./Mermaid.vue_vue_type_script_setup_true_lang-DolrJsfm.js";var t,e=(t=class{constructor(i){this.init=i,this.records=this.init()}reset(){this.records=this.init()}},s(t,"ImperativeState"),t);export{e as I};
