import{p as i}from"./treemap-KZPCXAKY-L5K4MMMF-BtDxM1mK.js";import{c as e,l as o,a8 as n,f as p}from"./Mermaid.vue_vue_type_script_setup_true_lang-DolrJsfm.js";import"./chunk-MFRUYFWM-BjrLk6MK.js";import"./index-Dgc7rSMr.js";import"./modules/vue-DkYzewYG.js";import"./modules/shiki-COU8xzp7.js";import"./modules/file-saver-B7oFTzqn.js";var g={parse:e(async r=>{const a=await i("info",r);o.debug(a)},"parse")},m={version:"11.13.0"},v=e(()=>m.version,"getVersion"),d={getVersion:v},c=e((r,a,s)=>{o.debug(`rendering info diagram
`+r);const t=n(a);p(t,100,400,!0),t.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${s}`)},"draw"),f={draw:c},z={parser:g,db:d,renderer:f};export{z as diagram};
