import{E as t,A as j,r as m,G as s,H as $}from"../modules/vue-DkYzewYG.js";import{i as f,a as C,b as x,c as S,d as p,e as v,f as E,h as R,H as T,F}from"../index-Dgc7rSMr.js";function D(){const n=t(R),o=s(n,"nav"),e=t(f).value,c=s(e,"current"),i=t(E),a=t(p),r=t(S,{}),l=t(v,void 0),u=t(x,m(1)),d=t(C,j(()=>1));return{$slidev:n,$nav:o,$clicksContext:e,$clicks:c,$page:i,$route:l,$renderContext:a,$frontmatter:r,$scale:u,$zoom:d}}function H(n,o){return{...$(n,o===0?T:F),frontmatter:n}}export{H as f,D as u};
