import{r as o,z as u,A as f}from"../modules/vue-DkYzewYG.js";import{g as s}from"../index-Dgc7rSMr.js";function c(n){return{info:o(s(n)?.meta.slide??null),update:async()=>{}}}const l={};function p(n){function t(e){return l[e]??=c(e)}return{info:f({get(){return t(u(n)).info.value},set(e){t(u(n)).info.value=e}}),update:async(e,r)=>{const i=t(r??u(n)),a=await i.update(e);return a&&(i.info.value=a),a}}}export{c as a,p as u};
