import{e as n,d as t,w as o,a as r,o as i,g as l,D as a}from"../modules/vue-DkYzewYG.js";import{_ as d}from"../index-Dgc7rSMr.js";import"../modules/shiki-COU8xzp7.js";const c={},f={class:"h-full w-full flex items-center justify-center gap-5 lt-md:flex-col"};function p(u,e){const s=r("RouterLink");return i(),n("div",f,[t(s,{to:"/",class:"page-link"},{default:o(()=>[...e[0]||(e[0]=[l("div",{class:"i-carbon:presentation-file"},null,-1),a(" Slides ",-1)])]),_:1}),t(s,{to:"/presenter",class:"page-link"},{default:o(()=>[...e[1]||(e[1]=[l("div",{class:"i-carbon:user-speaker"},null,-1),a(" Presenter ",-1)])]),_:1}),t(s,{to:"/notes",class:"page-link"},{default:o(()=>[...e[2]||(e[2]=[l("div",{class:"i-carbon:catalog"},null,-1),a(" Notes ",-1)])]),_:1}),t(s,{to:"/overview",class:"page-link"},{default:o(()=>[...e[3]||(e[3]=[l("div",{class:"i-carbon:list-boxes"},null,-1),a(" Overview ",-1)])]),_:1})])}const k=d(c,[["render",p],["__scopeId","data-v-471b148d"]]);export{k as default};
