import{o as a,b as p,w as l,g as t,v as n,x as i,z as s}from"./modules/vue-DkYzewYG.js";import{I as m}from"./slidev/default-D2jVc_dI.js";import{u,f as c}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const _="/tp/3-25/assets/image-1-C3GIgFHW.png",B={__name:"slides.md__slidev_9",setup(f){const{$clicksContext:o,$frontmatter:r}=u();return o.setup(),(d,e)=>(a(),p(m,n(i(s(c)(s(r),8))),{default:l(()=>[...e[0]||(e[0]=[t("p",null,[t("img",{src:_,alt:"alt text"})],-1),t("p",null,"因此，将问题建模为：",-1),t("p",null,"在单个基站的无线系统中，基站位于中心，覆盖半径内的N个设备。",-1),t("p",null,"假设该系统的时隙（timeslot）是同步的，并且每个设备需要发送的数据包的服务时间（service time）为一个时隙",-1)])]),_:1},16))}};export{B as default};
