import{f as u,O as l,J as m,P as c,o as i,e as p,n as f,z as t,r as d}from"../modules/vue-DkYzewYG.js";import{u as _}from"./SlideWrapper-CqdKCKqw.js";import{u as v}from"./context-CSCKgLWe.js";import"../index-Dgc7rSMr.js";import"../modules/shiki-COU8xzp7.js";const E=u({__name:"DrawingLayer",setup(g){const{drauu:e,drawingEnabled:o,loadCanvas:s}=_(),r=v().$scale,n=d();return l(()=>{e.mount(n.value,n.value.parentElement),m(r,a=>e.options.coordinateScale=1/a,{immediate:!0}),s()}),c(()=>{e.unmount()}),(a,w)=>(i(),p("svg",{ref_key:"svg",ref:n,class:f(["w-full h-full absolute top-0",{"pointer-events-none":!t(o),"touch-none":t(o)}])},null,2))}});export{E as default};
