.slidev-presenter[data-v-889c98ce]{--slidev-controls-foreground: current}.grid-container[data-v-889c98ce]{--slidev-presenter-notes-width: 360px;--slidev-presenter-notes-row-size: 280px;flex:1 1 0%;overflow:hidden;background-color:#9ca3af33;display:grid;gap:1px 1px}.grid-container.layout1[data-v-889c98ce]{grid-template-columns:var(--slidev-presenter-notes-width) minmax(0,1fr);grid-template-rows:minmax(0,2fr) minmax(0,var(--slidev-presenter-notes-row-size)) min-content;grid-template-areas:"main main" "note next" "bottom bottom"}.grid-container.layout2[data-v-889c98ce]{grid-template-columns:var(--slidev-presenter-notes-width) minmax(0,1fr);grid-template-rows:minmax(0,var(--slidev-presenter-notes-row-size)) minmax(0,1fr) min-content;grid-template-areas:"note main" "note next" "bottom bottom"}@media(max-aspect-ratio:3/5){.grid-container.layout1[data-v-889c98ce]{grid-template-columns:1fr;grid-template-rows:2fr 1fr 1fr min-content;grid-template-areas:"main" "note" "next" "bottom"}}@media(min-aspect-ratio:1/1){.grid-container.layout1[data-v-889c98ce]{grid-template-columns:minmax(0,1fr) minmax(0,1.1fr) var(--slidev-presenter-notes-width);grid-template-rows:minmax(0,1fr) minmax(0,var(--slidev-presenter-notes-row-size)) min-content;grid-template-areas:"main main next" "main main note" "bottom bottom bottom"}}.grid-container.layout3[data-v-889c98ce]{grid-template-columns:var(--slidev-presenter-notes-width) minmax(0,1fr);grid-template-rows:minmax(0,var(--slidev-presenter-notes-row-size)) minmax(0,1fr) min-content;grid-template-areas:"note next" "main next" "bottom bottom"}.grid-section[data-v-889c98ce]{--un-bg-opacity:1;background-color:rgb(255 255 255 / var(--un-bg-opacity))}.dark .grid-section[data-v-889c98ce]{--un-bg-opacity:1;background-color:rgb(18 18 18 / var(--un-bg-opacity))}.grid-section.top[data-v-889c98ce]{grid-area:top}.grid-section.main[data-v-889c98ce]{grid-area:main}.grid-section.next[data-v-889c98ce]{grid-area:next}.grid-section.note[data-v-889c98ce]{grid-area:note}.grid-section.bottom[data-v-889c98ce]{grid-area:bottom}.notes-resizer[data-v-889c98ce]{position:absolute;top:0;width:12px;height:100%;cursor:col-resize;z-index:10;touch-action:none}.notes-resizer[data-v-889c98ce]:before{content:"";position:absolute;left:50%;top:0;width:1px;height:100%;background-color:currentColor;opacity:.2;transform:translate(-50%)}.notes-row-resizer[data-v-889c98ce]{position:absolute;left:0;width:100%;height:12px;cursor:row-resize;z-index:10;touch-action:none}.notes-row-resizer[data-v-889c98ce]:before{content:"";position:absolute;left:0;top:50%;width:100%;height:1px;background-color:currentColor;opacity:.2;transform:translateY(-50%)}.notes-vertical-resizer[data-v-889c98ce]{position:absolute;right:var(--slidev-presenter-notes-width);top:0;bottom:var(--slidev-presenter-bottom-height, 0px);width:12px;cursor:col-resize;z-index:10;touch-action:none;transform:translate(50%)}.notes-vertical-resizer[data-v-889c98ce]:before{content:"";position:absolute;left:50%;top:0;width:1px;height:100%;background-color:currentColor;opacity:.2;transform:translate(-50%)}.notes-vertical-resizer-left[data-v-889c98ce]{position:absolute;left:var(--slidev-presenter-notes-width);top:0;bottom:var(--slidev-presenter-bottom-height, 0px);width:12px;cursor:col-resize;z-index:10;touch-action:none;transform:translate(-50%)}.notes-vertical-resizer-left[data-v-889c98ce]:before{content:"";position:absolute;left:50%;top:0;width:1px;height:100%;background-color:currentColor;opacity:.2;transform:translate(-50%)}
