import{f as c,o as u,e as d,g as t,i as m,k as p,A as f,b as _,w as v,v as C,x as g,z as r}from"../modules/vue-DkYzewYG.js";import{u as i,f as h}from"./context-CSCKgLWe.js";import"../index-Dgc7rSMr.js";import"../modules/shiki-COU8xzp7.js";function a(e){return e.startsWith("/")?"/tp/3-25"+e.slice(1):e}function k(e,s=!1){const l=e&&["#","rgb","hsl"].some(n=>e.indexOf(n)===0),o={background:l?e:void 0,color:e&&!l?"white":void 0,backgroundImage:l?void 0:e?s?`linear-gradient(#0005, #0008), url(${a(e)})`:`url("${a(e)}")`:void 0,backgroundRepeat:"no-repeat",backgroundPosition:"center",backgroundSize:"cover"};return o.background||delete o.background,o}const x={class:"my-auto w-full"},T=c({__name:"cover",props:{background:{default:""}},setup(e){i();const s=e,l=f(()=>k(s.background,!0));return(o,n)=>(u(),d("div",{class:"slidev-layout cover",style:p(l.value)},[t("div",x,[m(o.$slots,"default")])],4))}}),M={__name:"slides.md__slidev_1",setup(e){const{$clicksContext:s,$frontmatter:l}=i();return s.setup(),(o,n)=>(u(),_(T,C(g(r(h)(r(l),0))),{default:v(()=>[...n[0]||(n[0]=[t("h1",null,"3-19",-1),t("h2",null,"背景",-1),t("p",null,"随着物联网 (IoT) 应用的普及，联网设备的数量呈指数级增长。许多物联网应用都依赖于大规模机器类型通信 (mMTC) 技术（自动驾驶汽车、工业自动化和环境感知）。据预测，全球约一半的连接将是 mMTC 设备",-1),t("h3",null,"mMTC",-1),t("p",null,"mMTC的特征：",-1),t("ul",null,[t("li",null,"大量设备共享少量无线资源"),t("li",null,"设备通常只发送少量短数据包和上行链路数据"),t("li",null,"流量的间歇性：并非始终有数据要发送，每个时隙只有随机一部分设备接入网络")],-1),t("p",null,"在mMTC中，传统的中心化资源分配不可扩展，因为：",-1),t("ul",null,[t("li",null,"基站要给每个设备分配资源"),t("li",null,"需要频繁下发配置")],-1)])]),_:1},16))}};export{M as default};
