import{o as r,b as s,w as n,g as l,D as u,v as i,x as p,z as e}from"./modules/vue-DkYzewYG.js";import{I as m}from"./slidev/default-D2jVc_dI.js";import{u as c,f as d}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const v={__name:"slides.md__slidev_10",setup(f){const{$clicksContext:o,$frontmatter:a}=c();return o.setup(),(_,t)=>(r(),s(m,i(p(e(d)(e(a),9))),{default:n(()=>[...t[0]||(t[0]=[l("p",null,"其中：",-1),l("ul",null,[l("li",null,"每个设备 = 一个 agent"),l("li",null,"设备选择时隙 = agent选择资源单元"),l("li",null,[u("状态： "),l("ul",null,[l("li",null,"全局状态：网络整体情况、所有设备的流量、信道等"),l("li",null,"自己的流量情况、历史行为和选择各资源的成功率")])]),l("li",null,"平均成功传输率 = 奖励")],-1),l("p",null,"因此，将mMTC环境的通信建模为Dec-POMDP（分布式部分可观测马尔可夫决策过程",-1)])]),_:1},16))}};export{v as default};
