import{_ as o}from"./DrawingControls.vue_vue_type_style_index_0_lang-BKyAdcnS.js";import"../modules/vue-DkYzewYG.js";import"../modules/shiki-COU8xzp7.js";import"./SlideWrapper-CqdKCKqw.js";import"../index-Dgc7rSMr.js";import"./IconButton.vue_vue_type_script_setup_true_lang-Bk4_sWNY.js";import"./shortcuts-yzAyAoyn.js";import"./context-CSCKgLWe.js";import"../modules/unplugin-icons-ykXbDv9Z.js";export{o as default};
