import{o as e,b as o,w as r,g as a,D as t,v as i,x as c,z as n}from"./modules/vue-DkYzewYG.js";import{I as p}from"./slidev/default-D2jVc_dI.js";import{u,f as h}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const w={__name:"slides.md__slidev_4",setup(d){const{$clicksContext:l,$frontmatter:m}=u();return l.setup(),(g,s)=>(e(),o(p,i(c(n(h)(n(m),3))),{default:r(()=>[...s[0]||(s[0]=[a("h3",null,"多智能体强化学习：QMIX",-1),a("h4",null,"多智能体的困难",-1),a("ol",null,[a("li",null,[t("动作空间随智能体数量呈指数级增长的问题 "),a("ul",null,[a("li",null,"多智能体 = 多个决策同时发生，所有动作必须组合成一个“联合动作”"),a("li",null,[a("span",{class:"katex"},[a("span",{class:"katex-mathml"},[a("math",{xmlns:"http://www.w3.org/1998/Math/MathML"},[a("semantics",null,[a("mrow",null,[a("mi",{mathvariant:"normal"},"Σ"),a("mrow",null,[a("mtext",{mathvariant:"monospace"},"选择数"),a("mo",null,"="),a("mrow",null,[a("mrow",null,[a("mi",{mathvariant:"monospace"},"A"),a("mi",{mathvariant:"monospace"},"g"),a("mi",{mathvariant:"monospace"},"n"),a("mi",{mathvariant:"monospace"},"e"),a("mi",{mathvariant:"monospace"},"t"),a("mtext",{mathvariant:"monospace"},"数量")]),a("mo",null,"⋅"),a("mrow",null,[a("mi",{mathvariant:"monospace"},"A"),a("mi",{mathvariant:"monospace"},"g"),a("mi",{mathvariant:"monospace"},"e"),a("mi",{mathvariant:"monospace"},"n"),a("mi",{mathvariant:"monospace"},"t"),a("mtext",{mathvariant:"monospace"},"可选能力数量")])])])]),a("annotation",{encoding:"application/x-tex"},"\\Sigma\\tt{选择数}=\\tt{Agnet数量} \\cdot \\tt{Agent可选能力数量}")])])]),a("span",{class:"katex-html","aria-hidden":"true"},[a("span",{class:"base"},[a("span",{class:"strut",style:{height:"0.9055em","vertical-align":"-0.2222em"}}),a("span",{class:"mord"},"Σ"),a("span",{class:"mord"},[a("span",{class:"mord"},[a("span",{class:"mord mathtt cjk_fallback"},"选择数")]),a("span",{class:"mspace",style:{"margin-right":"0.2778em"}}),a("span",{class:"mrel"},"="),a("span",{class:"mspace",style:{"margin-right":"0.2778em"}}),a("span",{class:"mord"},[a("span",{class:"mord"},[a("span",{class:"mord mathtt"},"Agnet"),a("span",{class:"mord mathtt cjk_fallback"},"数量")]),a("span",{class:"mspace",style:{"margin-right":"0.2222em"}}),a("span",{class:"mbin"},"⋅"),a("span",{class:"mspace",style:{"margin-right":"0.2222em"}}),a("span",{class:"mord"},[a("span",{class:"mord"},[a("span",{class:"mord mathtt"},"Agent"),a("span",{class:"mord mathtt cjk_fallback"},"可选能力数量")])])])])])])])])])]),a("li",null,[t("部分可观测性和/或通信约束使得学习分散式策略 "),a("ul",null,[a("li",null,"Agent只能看到局部，每个Agent独立完成不完整信息决策")])]),a("li",null,[t("每个智能体的学习都会受到其他智能体学习和探索的干扰 "),a("ul",null,[a("li",null,"其他Agent也在学习，环境不固定")])])],-1),a("p",null,"QMIX解决的问题为：多智能体如何协同决策",-1)])]),_:1},16))}};export{w as default};
