import{o as s,b as a,w as n,g as t,v as u,x as i,z as e}from"./modules/vue-DkYzewYG.js";import{I as p}from"./slidev/default-D2jVc_dI.js";import{u as m,f as c}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const k={__name:"slides.md__slidev_2",setup(f){const{$clicksContext:r,$frontmatter:o}=m();return r.setup(),(_,l)=>(s(),a(p,u(i(e(c)(e(o),1))),{default:n(()=>[...l[0]||(l[0]=[t("h3",null,"已有的通信方案",-1),t("h4",null,"Grant-Free + NOMA",-1),t("ul",null,[t("li",null,"多个设备通过功率域或码域复用来复用相同的时频资源"),t("li",null,"基于竞争，设备直接向基站（BS）发送数据，无需请求和授权过程"),t("li",null,"冲突仍然存在")],-1),t("h3",null,"引入强化学习",-1),t("p",null,"用数据驱动方式解决网络优化问题，设备自主试错+学习",-1),t("p",null,"至此将mMTC接入问题视作多智能体强化学习问题",-1)])]),_:1},16))}};export{k as default};
