import{f as n,b as l,w as i,C as c,A as r,o as u,g as o,t as d,i as m,n as f}from"../modules/vue-DkYzewYG.js";const p={class:"sr-only"},y=n({__name:"IconButton",props:{title:{},icon:{},as:{},to:{}},setup(t){const e=t,s=r(()=>e.as||(e.to?"router-link":"button"));return(a,C)=>(u(),l(c(s.value),{class:"slidev-icon-btn",title:t.title,to:t.to},{default:i(()=>[o("span",p,d(t.title),1),m(a.$slots,"default",{},()=>[o("div",{class:f(t.icon)},null,2)])]),_:3},8,["title","to"]))}});export{y as _};
