import{s as a,c as s,a as e,C as t}from"./chunk-2WLNDWH6-BgIGPyjU.js";import{c as i}from"./Mermaid.vue_vue_type_script_setup_true_lang-DolrJsfm.js";import"./chunk-SBHDPRHC-BQwmDc8g.js";import"./chunk-SXA26SXQ-CwqRzfLv.js";import"./chunk-U2CUWHSV-CpgNQObm.js";import"./chunk-M4FGLBOT-7_RufB34.js";import"./modules/vue-DkYzewYG.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";import"./modules/file-saver-B7oFTzqn.js";var b={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{b as diagram};
