.range[data-v-d1ec9b7d]{-webkit-appearance:none;appearance:none;background:transparent}.range[data-v-d1ec9b7d]::-webkit-slider-thumb{-webkit-appearance:none;height:100%;width:var(--thumb-width, .5rem)}.range[data-v-d1ec9b7d]::-moz-range-thumb{height:100%;width:var(--thumb-width, .5rem)}.slidev-note :first-child{margin-top:0}
