import{s as r,b as e,a,S as s}from"./chunk-3VXWS7DV-Ctvu6Lk_.js";import{c as i}from"./Mermaid.vue_vue_type_script_setup_true_lang-DolrJsfm.js";import"./chunk-U2CUWHSV-CpgNQObm.js";import"./chunk-M4FGLBOT-7_RufB34.js";import"./modules/vue-DkYzewYG.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";import"./modules/file-saver-B7oFTzqn.js";var b={parser:a,get db(){return new s(2)},renderer:e,styles:r,init:i(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{b as diagram};
