.autocomplete-list[data-v-f86dd406]{margin-top:.25rem;--un-bg-opacity:1;background-color:rgb(255 255 255 / var(--un-bg-opacity));overflow:auto;max-height:calc(100vh - 100px)}.dark .autocomplete-list[data-v-f86dd406]{--un-bg-opacity:1;background-color:rgb(18 18 18 / var(--un-bg-opacity))}.autocomplete[data-v-f86dd406]{cursor:pointer}.slider{appearance:none;height:22px;outline:none;opacity:.7;-webkit-transition:.2s;transition:opacity .2s;overflow:hidden;border-width:1px;border-color:#9ca3af33;border-radius:.25rem;background-color:#9ca3af0d}.slider:hover{opacity:1}.slider::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;width:5px;height:22px;background:var(--slidev-theme-primary);cursor:pointer;z-index:10}.slider::-moz-range-thumb{width:5px;height:22px;background:var(--slidev-theme-primary);cursor:pointer;z-index:10}.item[data-v-ee1ed29b]{display:flex;cursor:default;gap:.25rem;white-space:nowrap;border-radius:.25rem;padding:.25rem .5rem}.item[data-v-ee1ed29b]:hover{--un-bg-opacity:1;background-color:rgb(156 163 175 / var(--un-bg-opacity));--un-bg-opacity:.1}.title[data-v-ee1ed29b]{-webkit-user-select:none;user-select:none;padding:.25rem .75rem;text-wrap:nowrap;font-size:.875rem;line-height:1.25rem;font-weight:700;opacity:.75}#slideshow[data-v-2fadd6c4]{height:100%}
