import{f,Y as m,e as _,g as o,D as a,t as r,z as x,b as u,w as i,j as c,A as v,a as g,o as n}from"../modules/vue-DkYzewYG.js";import{j as k,_ as h}from"../index-Dgc7rSMr.js";import"../modules/shiki-COU8xzp7.js";const N={class:"grid justify-center text-center pt-15% gap-5"},w={class:"text-2xl"},y={class:"op-60"},B={class:"mt-3 flex flex-col gap-2 max-w-xs mx-auto w-full"},C=f({__name:"404",setup(R){const{currentRoute:l}=m(),{total:d}=k(),s=v(()=>{const t=l.value.path.match(/\d+/);if(t){const e=+t[0];if(e>0&&e<=d.value)return e}return null});return(p,t)=>{const e=g("RouterLink");return n(),_("div",N,[o("div",null,[t[2]||(t[2]=o("h1",{class:"text-9xl font-light"}," 404 ",-1)),o("p",w,[t[0]||(t[0]=a(" Page ",-1)),o("code",y,r(x(l).path),1),t[1]||(t[1]=a(" not found ",-1))])]),o("div",B,[s.value!==1?(n(),u(e,{key:0,to:"/",class:"page-link"},{default:i(()=>[...t[3]||(t[3]=[a(" Go Home ",-1)])]),_:1})):c("v-if",!0),s.value?(n(),u(e,{key:1,to:`/${s.value}`,class:"page-link"},{default:i(()=>[a(" Go to Slide "+r(s.value),1)]),_:1},8,["to"])):c("v-if",!0)])])}}}),D=h(C,[["__scopeId","data-v-e4260d36"]]);export{D as default};
