.slidev-slide-container[data-v-99b9a080]{position:relative;width:100%;height:100%;overflow:hidden}.slidev-slide-content[data-v-99b9a080]{--slidev-slide-container-scale: var(--slidev-slide-scale);transform:translate(-50%,-50%) scale(var(--slidev-slide-scale));position:absolute;left:50%;top:50%;overflow:hidden;--un-bg-opacity:1;background-color:rgb(255 255 255 / var(--un-bg-opacity))}.dark .slidev-slide-content[data-v-99b9a080]{--un-bg-opacity:1;background-color:rgb(18 18 18 / var(--un-bg-opacity))}.disable-view-transition[data-v-ac6b3076] *{view-transition-name:none!important}.slidev-page[data-v-ac6b3076]{position:absolute;inset:0;--slidev-slide-zoom-scale: 1;width:calc(100% / var(--slidev-slide-zoom-scale));height:calc(100% / var(--slidev-slide-zoom-scale));transform-origin:top left;scale:var(--slidev-slide-zoom-scale);--slidev-slide-scale: calc(var(--slidev-slide-container-scale) * var(--slidev-slide-zoom-scale))}
