import{_ as p}from"./Mermaid.vue_vue_type_script_setup_true_lang-DolrJsfm.js";import{o as m,b as n,w as i,g as t,d as l,m as u,v as d,x as A,z as e}from"./modules/vue-DkYzewYG.js";import{I as _}from"./slidev/default-D2jVc_dI.js";import{u as f,f as c}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";import"./modules/file-saver-B7oFTzqn.js";const M={__name:"slides.md__slidev_3",setup(g){const{$clicksContext:r,$frontmatter:s}=f();return r.setup(),(B,o)=>{const a=p;return m(),n(_,d(A(e(c)(e(s),2))),{default:i(()=>[o[0]||(o[0]=t("h2",null,"强化学习",-1)),o[1]||(o[1]=t("p",null,"强化学习：智能体（Agent）与环境交互，根据反馈奖励来学会做决策",-1)),l(a,u({"code-lz":"OYJwhgDgFgBAMgJQFAEEDaAiQbU6EADAFAM4CUGAujALQUB8MAQpoBVKgOvJ5gnlW0DCmgapqBGpTwBHDpRowAIpkANprkIByDkA"},{}),null,16)]),_:1},16)}}};export{M as default};
