import{f as r,b as m,z as c,e as u,g as t,i as f,n as p,j as b,K as k,B as v,o as s}from"../modules/vue-DkYzewYG.js";const g={key:0,class:"fixed top-0 bottom-0 left-0 right-0 grid z-modal"},C=r({__name:"Modal",props:{modelValue:{default:!1},class:{default:""}},emits:["update:modelValue"],setup(l,{emit:n}){const e=l,a=v(e,"modelValue",n);function d(){a.value=!1}return(i,o)=>(s(),m(k,null,[c(a)?(s(),u("div",g,[t("div",{bg:"black opacity-80",class:"absolute top-0 bottom-0 left-0 right-0 -z-1",onClick:o[0]||(o[0]=_=>d())}),t("div",{class:p(["m-auto rounded-md bg-main shadow",e.class]),"dark:border":"~ main"},[f(i.$slots,"default")],2)])):b("v-if",!0)],1024))}});export{C as _};
