function O(r,w){for(var f=0;f<w.length;f++){const a=w[f];if(typeof a!="string"&&!Array.isArray(a)){for(const l in a)if(l!=="default"&&!(l in r)){const c=Object.getOwnPropertyDescriptor(a,l);c&&Object.defineProperty(r,l,c.get?c:{enumerable:!0,get:()=>a[l]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var p=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function A(r){return r&&r.__esModule&&Object.prototype.hasOwnProperty.call(r,"default")?r.default:r}var v={exports:{}},_=v.exports,j;function S(){return j||(j=1,(function(r,w){(function(f,a){a()})(_,function(){function f(e,t){return typeof t>"u"?t={autoBom:!1}:typeof t!="object"&&(console.warn("Deprecated: Expected third argument to be a object"),t={autoBom:!t}),t.autoBom&&/^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(e.type)?new Blob(["\uFEFF",e],{type:e.type}):e}function a(e,t,s){var n=new XMLHttpRequest;n.open("GET",e),n.responseType="blob",n.onload=function(){d(n.response,t,s)},n.onerror=function(){console.error("could not download file")},n.send()}function l(e){var t=new XMLHttpRequest;t.open("HEAD",e,!1);try{t.send()}catch{}return 200<=t.status&&299>=t.status}function c(e){try{e.dispatchEvent(new MouseEvent("click"))}catch{var t=document.createEvent("MouseEvents");t.initMouseEvent("click",!0,!0,window,0,0,0,80,20,!1,!1,!1,!1,0,null),e.dispatchEvent(t)}}var i=typeof window=="object"&&window.window===window?window:typeof self=="object"&&self.self===self?self:typeof p=="object"&&p.global===p?p:void 0,b=i.navigator&&/Macintosh/.test(navigator.userAgent)&&/AppleWebKit/.test(navigator.userAgent)&&!/Safari/.test(navigator.userAgent),d=i.saveAs||(typeof window!="object"||window!==i?function(){}:"download"in HTMLAnchorElement.prototype&&!b?function(e,t,s){var n=i.URL||i.webkitURL,o=document.createElement("a");t=t||e.name||"download",o.download=t,o.rel="noopener",typeof e=="string"?(o.href=e,o.origin===location.origin?c(o):l(o.href)?a(e,t,s):c(o,o.target="_blank")):(o.href=n.createObjectURL(e),setTimeout(function(){n.revokeObjectURL(o.href)},4e4),setTimeout(function(){c(o)},0))}:"msSaveOrOpenBlob"in navigator?function(e,t,s){if(t=t||e.name||"download",typeof e!="string")navigator.msSaveOrOpenBlob(f(e,s),t);else if(l(e))a(e,t,s);else{var n=document.createElement("a");n.href=e,n.target="_blank",setTimeout(function(){c(n)})}}:function(e,t,s,n){if(n=n||open("","_blank"),n&&(n.document.title=n.document.body.innerText="downloading..."),typeof e=="string")return a(e,t,s);var o=e.type==="application/octet-stream",E=/constructor/i.test(i.HTMLElement)||i.safari,h=/CriOS\/[\d]+/.test(navigator.userAgent);if((h||o&&E||b)&&typeof FileReader<"u"){var m=new FileReader;m.onloadend=function(){var u=m.result;u=h?u:u.replace(/^data:[^;]*;/,"data:attachment/file;"),n?n.location.href=u:location=u,n=null},m.readAsDataURL(e)}else{var g=i.URL||i.webkitURL,y=g.createObjectURL(e);n?n.location=y:location.href=y,n=null,setTimeout(function(){g.revokeObjectURL(y)},4e4)}});i.saveAs=d.saveAs=d,r.exports=d})})(v)),v.exports}var R=S();const F=O({__proto__:null},[R]);export{F,A as g};
