import{o as e,b as n,w as r,g as s,v as p,x as i,z as t}from"./modules/vue-DkYzewYG.js";import{I as c}from"./slidev/default-D2jVc_dI.js";import{u as o,f as u}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const k={__name:"slides.md__slidev_11",setup(g){const{$clicksContext:m,$frontmatter:l}=o();return m.setup(),(h,a)=>(e(),n(c,p(i(t(u)(t(l),10))),{default:r(()=>[...a[0]||(a[0]=[s("p",null,"可用",-1),s("p",null,[s("span",{class:"katex-display"},[s("span",{class:"katex"},[s("span",{class:"katex-mathml"},[s("math",{xmlns:"http://www.w3.org/1998/Math/MathML",display:"block"},[s("semantics",null,[s("mrow",null,[s("mi",null,"G"),s("mo",null,"="),s("mo",{stretchy:"false"},"{"),s("msup",null,[s("mi",null,"N"),s("mo",{mathvariant:"normal",lspace:"0em",rspace:"0em"},"′")]),s("mo",{separator:"true"},","),s("mi",null,"S"),s("mo",{separator:"true"},","),s("mi",null,"U"),s("mo",{separator:"true"},","),s("mi",null,"P"),s("mo",{separator:"true"},","),s("mi",null,"r"),s("mo",{separator:"true"},","),s("mi",null,"Z"),s("mo",{separator:"true"},","),s("mi",null,"γ"),s("mo",{stretchy:"false"},"}")]),s("annotation",{encoding:"application/x-tex"},"G = \\{N',S,U,P,r,Z,\\gamma\\} ")])])]),s("span",{class:"katex-html","aria-hidden":"true"},[s("span",{class:"base"},[s("span",{class:"strut",style:{height:"0.6833em"}}),s("span",{class:"mord mathnormal"},"G"),s("span",{class:"mspace",style:{"margin-right":"0.2778em"}}),s("span",{class:"mrel"},"="),s("span",{class:"mspace",style:{"margin-right":"0.2778em"}})]),s("span",{class:"base"},[s("span",{class:"strut",style:{height:"1.0519em","vertical-align":"-0.25em"}}),s("span",{class:"mopen"},"{"),s("span",{class:"mord"},[s("span",{class:"mord mathnormal",style:{"margin-right":"0.10903em"}},"N"),s("span",{class:"msupsub"},[s("span",{class:"vlist-t"},[s("span",{class:"vlist-r"},[s("span",{class:"vlist",style:{height:"0.8019em"}},[s("span",{style:{top:"-3.113em","margin-right":"0.05em"}},[s("span",{class:"pstrut",style:{height:"2.7em"}}),s("span",{class:"sizing reset-size6 size3 mtight"},[s("span",{class:"mord mtight"},[s("span",{class:"mord mtight"},"′")])])])])])])])]),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.05764em"}},"S"),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.10903em"}},"U"),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.13889em"}},"P"),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.02778em"}},"r"),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.07153em"}},"Z"),s("span",{class:"mpunct"},","),s("span",{class:"mspace",style:{"margin-right":"0.1667em"}}),s("span",{class:"mord mathnormal",style:{"margin-right":"0.05556em"}},"γ"),s("span",{class:"mclose"},"}")])])])])],-1),s("p",null,"定义，该系统中包含N个agent，s ∈ S 表示环境的真实状态。该状态是智能体训练时网络仿真程序的状态部署时基站和信道质量的状态。在每个时隙中，每个设备 i ∈ {1, …, N} 选择一个动作 u^i ∈ U，该动作代表一个资源单元。其中，U 是一组资源，分配给一组设备。该组所有设备的动作构成联合动作 u = (u, …, u) ∈ U。如果在状态 s 下联合动作为 u，则系统的下一个状态可以根据状态转移函数 P(s’|s, u): S × U → S 获得。每个设备只能获取局部观测 z ∈ Z，而无法访问全局状态s。同时，设备之间独立决策且不进行通信。最终目标是通过学习策略最大化长期累积奖励，其中奖励函数r(s,u) 用于衡量系统的传输成功率，从而间接最小化接入时延。",-1)])]),_:1},16))}};export{k as default};
