import{o as s,b as a,w as n,g as t,v as u,x as i,z as l}from"./modules/vue-DkYzewYG.js";import{I as p}from"./slidev/default-D2jVc_dI.js";import{u as m,f as c}from"./slidev/context-CSCKgLWe.js";import"./index-Dgc7rSMr.js";import"./modules/shiki-COU8xzp7.js";const b={__name:"slides.md__slidev_8",setup(f){const{$clicksContext:o,$frontmatter:r}=m();return o.setup(),(_,e)=>(s(),a(p,u(i(l(c)(l(r),7))),{default:n(()=>[...e[0]||(e[0]=[t("h2",null,"系统建模",-1),t("blockquote",null,[t("p",null,"将mMTC环境的通信建模为Dec-POMDP（分布式部分可观测马尔可夫决策过程）")],-1),t("p",null,"从通信的角度：",-1),t("ul",null,[t("li",null,"一个区域内有多个设备"),t("li",null,"对每个设备，可以选择不同的时隙发送数据"),t("li",null,"如果多个设备选择同一时许，则发生冲突（back-off）")],-1)])]),_:1},16))}};export{b as default};
